@@ -35,7 +35,7 @@ class ConfigAlgo(Config):
         help_string="Include forks?",
         default=False,
     )
-    owner = ParamCreator.create_str_or_none(
+    owner_login = ParamCreator.create_str_or_none(
         help_string="Only include repos owned by this owner (None for dont mind)",
         default=None,
     )
