@@ -24,8 +24,8 @@ def yield_repos():
         if not ConfigAlgo.fork and repo.fork:
             reason = "repo is a fork"
             skip = True
-        if ConfigAlgo.owner is not None and repo.owner.name != ConfigAlgo.owner:
-            reason = f"wrong owner [{repo.owner.name}]"
+        if ConfigAlgo.owner_login is not None and repo.owner.login != ConfigAlgo.owner_login:
+            reason = f"wrong owner [{repo.owner.login}]"
             skip = True
         if not ConfigAlgo.private and repo.private:
             reason = "repo is private"
@@ -66,7 +66,7 @@ def fix_website() -> None:
 def repos_list() -> None:
     for repo in yield_repos():
         if ConfigOutput.verbose:
-            json.dump(obj=repo, fp=sys.stdout)
+            json.dump(obj=repo.raw_data, fp=sys.stdout, indent=4, sort_keys=True)
         else:
             print(f"{repo.name}")
 
